@@ -4,16 +4,6 @@ from SystemConfiguration import *
 import SystemConfiguration
 import os
 
-try:
-    unicode
-except NameError:
-    unicode = str
-
-try:
-    long
-except NameError:
-    long = int
-
 class TestSCDynamicStore (TestCase):
     def testTypes(self):
         self.assertTrue(isinstance(SCDynamicStoreRef, objc.objc_class))
@@ -119,6 +109,9 @@ class TestSCDynamicStore (TestCase):
 
 
 
+    @min_os_level('10.6')
+    def testFunctions10_6(self):
+        self.assertResultIsBOOL(SCDynamicStoreSetDispatchQueue)
 
 
 
