@@ -3,16 +3,6 @@ from PyObjCTools.TestSupport import *
 from SystemConfiguration import *
 import sys
 
-try:
-    unicode
-except NameError:
-    unicode = str
-
-try:
-    long
-except NameError:
-    long = int
-
 class TestSCNetworkConfiguration (TestCase):
 
     def testTypes(self):
@@ -62,6 +52,11 @@ class TestSCNetworkConfiguration (TestCase):
         self.assertTrue(isinstance(kSCNetworkProtocolTypeProxies, unicode))
         self.assertTrue(isinstance(kSCNetworkProtocolTypeSMB, unicode))
 
+    @min_os_level('10.6')
+    def testConstants10_5(self):
+        self.assertIsInstance(kSCNetworkInterfaceTypeIPSec, unicode)
+
+    @onlyIf(sys.byteorder == 'little', "Explained crashes on PPC")
     def testFunctions(self):
         r = SCNetworkInterfaceGetTypeID()
         self.assertTrue(isinstance(r, (int, long)))
@@ -73,6 +68,7 @@ class TestSCNetworkConfiguration (TestCase):
         for iface in r:
             if SCNetworkInterfaceGetBSDName(iface).startswith('en'):
                 break
+        
         r = SCNetworkInterfaceGetSupportedInterfaceTypes(iface)
         self.assertTrue(isinstance(r, CFArrayRef))
         self.assertTrue(isinstance(r[0], unicode))
@@ -108,6 +104,7 @@ class TestSCNetworkConfiguration (TestCase):
         r = SCNetworkInterfaceSetConfiguration(iface, {})
         self.assertTrue(r is True or r is False)
 
+
         r = SCNetworkInterfaceSetExtendedConfiguration(iface, "OC", {})
         self.assertTrue(r is True or r is False)
 
@@ -126,29 +123,21 @@ class TestSCNetworkConfiguration (TestCase):
         r = SCNetworkInterfaceCopyMediaSubTypeOptions(available, r[0])
         self.assertTrue(isinstance(r, CFArrayRef))
 
-        if sys.byteorder == 'little':
-            # These tests crash in Rosetta on an intel machine::
-            #
-            #   Unhandled transform (1) for ioctl group = 105 (i), number = 68, length = 32
-            #   Illegal instruction
+        r, mtu_cur, mtu_min, mtu_max = SCNetworkInterfaceCopyMTU(iface, None, None, None)
+        self.assertTrue(r is True)
+        self.assertTrue(isinstance(mtu_cur, (int, long)))
+        self.assertTrue(isinstance(mtu_min, (int, long)))
+        self.assertTrue(isinstance(mtu_max, (int, long)))
+        r = SCNetworkInterfaceSetMediaOptions(iface,
+            current['MediaSubType'],
+            current['MediaOptions'])
+        self.assertTrue(r is True or r is False)
 
-            # I haven't filed a bug for this yet.
+        r = SCNetworkInterfaceSetMTU(iface, mtu_cur)
+        self.assertTrue(r is True or r is False)
 
-            r, mtu_cur, mtu_min, mtu_max = SCNetworkInterfaceCopyMTU(iface, None, None, None)
-            self.assertTrue(r is True)
-            self.assertTrue(isinstance(mtu_cur, (int, long)))
-            self.assertTrue(isinstance(mtu_min, (int, long)))
-            self.assertTrue(isinstance(mtu_max, (int, long)))
-            r = SCNetworkInterfaceSetMediaOptions(iface,
-                current['MediaSubType'],
-                current['MediaOptions'])
-            self.assertTrue(r is True or r is False)
-
-            r = SCNetworkInterfaceSetMTU(iface, mtu_cur)
-            self.assertTrue(r is True or r is False)
-
-            r = SCNetworkInterfaceForceConfigurationRefresh(iface)
-            self.assertTrue(r is True or r is False)
+        r = SCNetworkInterfaceForceConfigurationRefresh(iface)
+        self.assertTrue(r is True or r is False)
 
         prefs = SCPreferencesCreate(None, "SystemConfiguration", None)
         self.assertTrue(isinstance(prefs, SCPreferencesRef))
@@ -159,6 +148,7 @@ class TestSCNetworkConfiguration (TestCase):
         a = SCBondInterfaceCopyAvailableMemberInterfaces(prefs)
         self.assertTrue(isinstance(a, CFArrayRef))
 
+        self.assertResultIsCFRetained(SCBondInterfaceCreate)
         iface = SCBondInterfaceCreate(prefs)
         self.assertTrue(iface is None or isinstance(iface, SCBondInterfaceRef))
 
@@ -229,6 +219,16 @@ class TestSCNetworkConfiguration (TestCase):
             r = SCVLANInterfaceRemove(iface)
             self.assertTrue(r is True)
 
+        self.assertResultIsCFRetained(SCVLANInterfaceCreate)
+        SCVLANInterfaceRemove
+        SCVLANInterfaceGetPhysicalInterface
+        SCVLANInterfaceGetTag
+        SCVLANInterfaceGetOptions
+        SCVLANInterfaceSetPhysicalInterfaceAndTag
+        SCVLANInterfaceSetLocalizedDisplayName
+        SCVLANInterfaceSetOptions
+
+
         r = SCNetworkProtocolGetTypeID()
         self.assertTrue(isinstance(r, (int, long)))
 
@@ -345,6 +345,8 @@ class TestSCNetworkConfiguration (TestCase):
         v = SCNetworkSetSetCurrent(SCNetworkSetCopyCurrent(prefs))
         self.assertIsInstance(v, bool)
 
+        self.assertResultIsBOOL(SCNetworkSetRemoveService)
+
 
     @min_os_level('10.5')
     def testFunctions10_5(self):
